@@ -25,7 +25,7 @@ PG_FUNCTION_INFO_V1(dbms_alert_waitany);
 PG_FUNCTION_INFO_V1(dbms_alert_waitone);
 PG_FUNCTION_INFO_V1(dbms_alert_defered_signal);
 
-extern unsigned int sid;
+extern int sid;
 float8 sensitivity = 250.0;
 extern LWLockId shmem_lockid;
 
