@@ -47,14 +47,22 @@ extern Oid	equality_oper_funcid(Oid argtype);
 /*
  * Date utils
  */
-#if PG_VERSION_NUM >= 90400
 #define STRING_PTR_FIELD_TYPE const char *const
-#else
-#define STRING_PTR_FIELD_TYPE char *
-#endif
 
 extern STRING_PTR_FIELD_TYPE ora_days[];
 
-extern int ora_seq_search(const char *name, STRING_PTR_FIELD_TYPE array[], int max);
+extern int ora_seq_search(const char *name, STRING_PTR_FIELD_TYPE array[], size_t max);
+
+#ifdef _MSC_VER
+
+#define int2size(v)			(size_t)(v)
+#define size2int(v)			(int)(v)
+
+#else
+
+#define int2size(v)			v
+#define size2int(v)			v
+
+#endif
 
 #endif
