@@ -134,7 +134,7 @@ typedef struct
 	alert_event *events;
 	alert_lock *locks;
 	size_t size;
-	unsigned int sid;
+	int sid;
 	vardata data[1]; /* flexible array member */
 } sh_memory;
 
@@ -149,7 +149,7 @@ pipe* pipes = NULL;
 
 LWLockId shmem_lockid = NOT_INITIALIZED;;
 
-unsigned int sid;                                 /* session id */
+int sid;                                 /* session id */
 
 extern alert_event *events;
 extern alert_lock  *locks;
@@ -1179,16 +1179,9 @@ dbms_pipe_create_pipe (PG_FUNCTION_ARGS)
 
 				p->uid = GetUserId();
 
-#if PG_VERSION_NUM >= 90500
-
 				user = (char*)DirectFunctionCall1(namein,
 					    CStringGetDatum(GetUserNameFromId(p->uid, false)));
 
-#else
-
-				user = (char*)DirectFunctionCall1(namein, CStringGetDatum(GetUserNameFromId(p->uid)));
-#endif
-
 				p->creator = ora_sstrcpy(user);
 				pfree(user);
 			}
