@@ -93,3 +93,9 @@ SELECT lengthb('');
 
 -- returs 't'
 SELECT lengthb(NULL) IS NULL;
+
+-- null safe concat (disabled by default)
+SELECT NULL || 'hello'::varchar2 || NULL;
+
+SET orafce.varchar2_null_safe_concat TO true;
+SELECT NULL || 'hello'::varchar2 || NULL;
