@@ -8,7 +8,6 @@
 
 #include "postgres.h"
 #include "access/hash.h"
-#include "access/tuptoaster.h"
 #include "libpq/pqformat.h"
 #include "nodes/nodeFuncs.h"
 #include "utils/array.h"
@@ -53,12 +52,11 @@ varchar2_input(const char *s, size_t len, int32 atttypmod)
 	 * Perform the typmod check; error out if value too long for VARCHAR2
 	 */
 	if (atttypmod >= (int32) VARHDRSZ && len > maxlen)
-		if (len > maxlen)
-			ereport(ERROR,
-					(errcode(ERRCODE_INVALID_PARAMETER_VALUE),
-						errmsg("input value length is %zd; too long for type varchar2(%zd)", len , maxlen)));
+		ereport(ERROR,
+				(errcode(ERRCODE_INVALID_PARAMETER_VALUE),
+					errmsg("input value length is %zd; too long for type varchar2(%zd)", len , maxlen)));
 
-	result = (VarChar *) cstring_to_text_with_len(s, len);
+	result = (VarChar *) cstring_to_text_with_len(s, size2int(len));
 	return  result;
 }
 
